@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2016 The PHP Group                                |
+   | Copyright (c) 1997-2018 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -314,16 +314,52 @@ php_apache_sapi_flush(void *server_context)
 	}
 }
 
-static void php_apache_sapi_log_message(char *msg)
+static void php_apache_sapi_log_message(char *msg, int syslog_type_int)
 {
 	php_struct *ctx;
+	int aplog_type = APLOG_ERR;
 
 	ctx = SG(server_context);
 
+	switch (syslog_type_int) {
+#if LOG_EMERG != LOG_CRIT
+		case LOG_EMERG:
+			aplog_type = APLOG_EMERG;
+			break;
+#endif
+#if LOG_ALERT != LOG_CRIT
+		case LOG_ALERT:
+			aplog_type = APLOG_ALERT;
+			break;
+#endif
+		case LOG_CRIT:
+			aplog_type = APLOG_CRIT;
+			break;
+		case LOG_ERR:
+			aplog_type = APLOG_ERR;
+			break;
+		case LOG_WARNING:
+			aplog_type = APLOG_WARNING;
+			break;
+		case LOG_NOTICE:
+			aplog_type = APLOG_NOTICE;
+			break;
+#if LOG_INFO != LOG_NOTICE
+		case LOG_INFO:
+			aplog_type = APLOG_INFO;
+			break;
+#endif
+#if LOG_NOTICE != LOG_DEBUG
+		case LOG_DEBUG:
+			aplog_type = APLOG_DEBUG;
+			break;
+#endif
+	}
+
 	if (ctx == NULL) { /* we haven't initialized our ctx yet, oh well */
 		ap_log_error(APLOG_MARK, APLOG_ERR | APLOG_STARTUP, 0, NULL, "%s", msg);
 	} else {
-		ap_log_rerror(APLOG_MARK, APLOG_ERR, 0, ctx->r, "%s", msg);
+		ap_log_rerror(APLOG_MARK, aplog_type, 0, ctx->r, "%s", msg);
 	}
 }
 
@@ -332,7 +368,7 @@ static void php_apache_sapi_log_message_ex(char *msg, request_rec *r)
 	if (r) {
 		ap_log_rerror(APLOG_MARK, APLOG_ERR, 0, r, msg, r->filename);
 	} else {
-		php_apache_sapi_log_message(msg);
+		php_apache_sapi_log_message(msg, -1);
 	}
 }
 
@@ -456,9 +492,7 @@ php_apache_server_startup(apr_pool_t *pconf, apr_pool_t *plog, apr_pool_t *ptemp
 	ZEND_TSRMLS_CACHE_UPDATE();
 #endif
 
-#ifdef ZEND_SIGNALS
 	zend_signal_startup();
-#endif
 
 	sapi_startup(&apache2_sapi_module);
 	apache2_sapi_module.startup(&apache2_sapi_module);
